# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 15:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0003_auto_20190121_1541'),
    ]

    operations = [
        migrations.RenameField(
            model_name='project',
            old_name='members',
            new_name='team',
        ),
    ]



"""djangoldp project URL Configuration"""
from django.conf.urls import url
from djangoldp.views import LDPViewSet

from .views import ProjectViewSet
from .models import Project, Customer

urlpatterns = [
    url(r'^projects/', ProjectViewSet.urls()),
    url(r'^customers/', LDPViewSet.urls(model=Customer)),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 15:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_project', '0002_move_jabber'),
    ]

    operations = [
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.RemoveField(
            model_name='project',
            name='team',
        ),
        migrations.AddField(
            model_name='customer',
            name='companyRegister',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactFirstName',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactLastName',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactMail',
            field=models.EmailField(default='', max_length=254),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactPhone',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='businessProvider',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='businessProviderFee',
            field=models.PositiveIntegerField(blank=True, default='0'),
        ),
        migrations.AddField(
            model_name='job',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djangoldp_project.Project'),
        ),
        migrations.AddField(
            model_name='job',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='project',
            name='members',
            field=models.ManyToManyField(blank=True, through='djangoldp_project.Job', to=settings.AUTH_USER_MODEL),
        ),
    ]



from oidc_provider.views import userinfo
from django.http import HttpResponse
from djangoldp.views import LDPViewSet
from .models import Project
import requests

class ProjectViewSet(LDPViewSet):
    model = Project
    permission_classes = []
    nested_fields = ["team"]

    def update(self, request, *args, **kwargs):
        response = super().update(request, *args, **kwargs)
        requests.post("https://jabber.happy-dev.fr/happydev_muc_admin/", json={"@context": "https://cdn.happy-dev.fr/owl/hdcontext.jsonld", "@graph": [{"object":self.get_object().get_absolute_url(),"type":"Update"}]})
        return response



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 17:01
from __future__ import unicode_literals

from django.db import migrations, models

def migrate_data(apps, schema_editor):
    Project = apps.get_model('djangoldp_project', 'Project')
    for project in Project.objects.all():
        project.jabberID = project.chatConfig.jabberID
        project.jabberRoom = project.chatConfig.jabberRoom
        project.save()

class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0002_move_jabber'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='jabberID',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='jabberRoom',
            field=models.BooleanField(default=True),
        ),
        migrations.RunPython(migrate_data),
    ]
